Vincent Povirk : ole32: Rename stream.ownerProperty to dirEntry.

Alexandre Julliard julliard at winehq.org
Mon Nov 16 11:43:51 CST 2009


Module: wine
Branch: master
Commit: df960e27c40875911c42532270d09393f7836afd
URL:    http://source.winehq.org/git/wine.git/?a=commit;h=df960e27c40875911c42532270d09393f7836afd

Author: Vincent Povirk <vincent at codeweavers.com>
Date:   Thu Nov 12 13:25:10 2009 -0600

ole32: Rename stream.ownerProperty to dirEntry.

---

 dlls/ole32/stg_stream.c |   24 ++++++++++++------------
 dlls/ole32/storage32.c  |    2 +-
 dlls/ole32/storage32.h  |    6 +++---
 3 files changed, 16 insertions(+), 16 deletions(-)

diff --git a/dlls/ole32/stg_stream.c b/dlls/ole32/stg_stream.c
index 4cc114a..e3ca9a1 100644
--- a/dlls/ole32/stg_stream.c
+++ b/dlls/ole32/stg_stream.c
@@ -209,7 +209,7 @@ static void StgStreamImpl_OpenBlockChain(
    * Read the information from the property.
    */
   readSuccessful = StorageImpl_ReadDirEntry(This->parentStorage->ancestorStorage,
-					     This->ownerProperty,
+					     This->dirEntry,
 					     &curProperty);
 
   if (readSuccessful)
@@ -233,14 +233,14 @@ static void StgStreamImpl_OpenBlockChain(
 	This->smallBlockChain = SmallBlockChainStream_Construct(
 								This->parentStorage->ancestorStorage,
 								NULL,
-								This->ownerProperty);
+								This->dirEntry);
       }
       else
       {
 	This->bigBlockChain = BlockChainStream_Construct(
 							 This->parentStorage->ancestorStorage,
 							 NULL,
-							 This->ownerProperty);
+							 This->dirEntry);
       }
     }
   }
@@ -591,14 +591,14 @@ static HRESULT WINAPI StgStreamImpl_SetSize(
       This->smallBlockChain = SmallBlockChainStream_Construct(
                                     This->parentStorage->ancestorStorage,
                                     NULL,
-                                    This->ownerProperty);
+                                    This->dirEntry);
     }
     else
     {
       This->bigBlockChain = BlockChainStream_Construct(
                                 This->parentStorage->ancestorStorage,
                                 NULL,
-                                This->ownerProperty);
+                                This->dirEntry);
     }
   }
 
@@ -606,7 +606,7 @@ static HRESULT WINAPI StgStreamImpl_SetSize(
    * Read this stream's property to see if it's small blocks or big blocks
    */
   Success = StorageImpl_ReadDirEntry(This->parentStorage->ancestorStorage,
-                                       This->ownerProperty,
+                                       This->dirEntry,
                                        &curProperty);
   /*
    * Determine if we have to switch from small to big blocks or vice versa
@@ -651,7 +651,7 @@ static HRESULT WINAPI StgStreamImpl_SetSize(
    * Write the new information about this stream to the property
    */
   Success = StorageImpl_ReadDirEntry(This->parentStorage->ancestorStorage,
-                                       This->ownerProperty,
+                                       This->dirEntry,
                                        &curProperty);
 
   curProperty.size.u.HighPart = libNewSize.u.HighPart;
@@ -660,7 +660,7 @@ static HRESULT WINAPI StgStreamImpl_SetSize(
   if (Success)
   {
     StorageImpl_WriteDirEntry(This->parentStorage->ancestorStorage,
-				This->ownerProperty,
+				This->dirEntry,
 				&curProperty);
   }
 
@@ -853,7 +853,7 @@ static HRESULT WINAPI StgStreamImpl_Stat(
    * Read the information from the property.
    */
   readSuccessful = StorageImpl_ReadDirEntry(This->parentStorage->ancestorStorage,
-					     This->ownerProperty,
+					     This->dirEntry,
 					     &curProperty);
 
   if (readSuccessful)
@@ -910,7 +910,7 @@ static HRESULT WINAPI StgStreamImpl_Clone(
   if ( ppstm == 0 )
     return STG_E_INVALIDPOINTER;
 
-  new_stream = StgStreamImpl_Construct (This->parentStorage, This->grfMode, This->ownerProperty);
+  new_stream = StgStreamImpl_Construct (This->parentStorage, This->grfMode, This->dirEntry);
 
   if (!new_stream)
     return STG_E_INSUFFICIENTMEMORY; /* Currently the only reason for new_stream=0 */
@@ -962,7 +962,7 @@ static const IStreamVtbl StgStreamImpl_Vtbl =
 StgStreamImpl* StgStreamImpl_Construct(
 		StorageBaseImpl* parentStorage,
     DWORD            grfMode,
-    ULONG            ownerProperty)
+    ULONG            dirEntry)
 {
   StgStreamImpl* newStream;
 
@@ -991,7 +991,7 @@ StgStreamImpl* StgStreamImpl_Construct(
      */
 
     newStream->grfMode = grfMode;
-    newStream->ownerProperty = ownerProperty;
+    newStream->dirEntry = dirEntry;
 
     /*
      * Start the stream at the beginning.
diff --git a/dlls/ole32/storage32.c b/dlls/ole32/storage32.c
index f2d856b..0bff0f4 100644
--- a/dlls/ole32/storage32.c
+++ b/dlls/ole32/storage32.c
@@ -827,7 +827,7 @@ static HRESULT WINAPI StorageBaseImpl_CreateStream(
 
       LIST_FOR_EACH_ENTRY(strm, &This->strmHead, StgStreamImpl, StrmListEntry)
       {
-        if (strm->ownerProperty == foundPropertyIndex)
+        if (strm->dirEntry == foundPropertyIndex)
         {
           TRACE("Stream deleted %p\n", strm);
           strm->parentStorage = NULL;
diff --git a/dlls/ole32/storage32.h b/dlls/ole32/storage32.h
index cc5d267..566e541 100644
--- a/dlls/ole32/storage32.h
+++ b/dlls/ole32/storage32.h
@@ -352,9 +352,9 @@ struct StgStreamImpl
   DWORD grfMode;
 
   /*
    * Index of the property that owns (points to) this stream.
    */
-  ULONG              ownerProperty;
+  ULONG              dirEntry;
 
   /*
    * Helper variable that contains the size of the stream
@@ -381,7 +381,7 @@ struct StgStreamImpl
 StgStreamImpl* StgStreamImpl_Construct(
 		StorageBaseImpl* parentStorage,
     DWORD            grfMode,
-    ULONG            ownerProperty);
+    ULONG            dirEntry);
 
 
 /******************************************************************************
@@ -352,9 +352,9 @@ struct StgStreamImpl
 
   /*
-   * Index of the property that owns (points to) this stream.
+   * Index of the directory entry that owns (points to) this stream.
    */




More information about the wine-cvs mailing list